----------------------------------------------------------------------------------

-- LGP-30 drum computer simulation
-- CRT module (register output - three traces on external CRT)
--
-- jm 1.8.2016

-- External scope to be connected in Y(t) mode.
-- Derive Y signal via resistor network connecting trace and offset outputs.
-- Note that the bit order on the display will be reversed vs. the LGP-30,
-- since LGP-30 uses right-to-left sweep of the beam! 

-- Order of displayed traces (bottom to top) is A, R, C.

----------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;


entity crt is
	port (
	
		-- all registers are presented during each word cycle
		A: in std_logic;			-- accumulator to display
		R: in std_logic;			-- instruction register to display
		C: in std_logic;			-- program counter to display
		
		-- trigger
		-- triggers horizontal deflection (right to left!) and 3-step counter for vertical offset
		T: in std_logic;			-- bit clock
		t3: in std_logic;			-- high during sign bit cycle
		
		-- output to external scope
		trace: out std_logic;	-- trace - alternates between A, R, C
		offset: buffer std_logic_vector (1 downto 0);	-- vertical offsets  alternate between 00, 01, 11
		trig: out std_logic		-- trigger 
	);
end crt;

architecture Behavioral of crt is

	-- signal offset_int: std_logic_vector (1 downto 0) := "00";

begin

	-- external trigger signal
	trig <= t3;
	
	process (T)
	begin
		if rising_edge (T) then
			-- offset signals,
			-- cycle through "00", "01", "11".
			if (t3 = '1') then
				if offset = "00" then offset <= "01";
				elsif offset = "01" then offset <= "11";
				else offset <= "00";
				end if;
			end if;
		end if;
	end process;	

	process (A, R, C, offset) is
	begin
		-- output trace; cycles through A, R, C 
		if offset = "00" then trace <= A;
		elsif offset = "01" then trace <= R;
		else trace <= C;
		end if;	
	end process;
	
end Behavioral;

