----------------------------------------------------------------------------------
--
-- Pixel clock and 5x pixel clock for DDR output registers.
--
-- 100 MHz input clock (Numato Mimas system clock);
-- 65 MHz pixel clock (XGA 1024*768 @ 60Hz).
-- Generate both from the same PLL to ensure phase match.
-- 
-- jm 1.6.2016
--
----------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library UNISIM;
use UNISIM.VComponents.all;

entity xga_clocks is
	Port ( 
		clk100: 			in  STD_LOGIC;
      pixel_clock: 	out STD_LOGIC;
		clock_5x: 		out STD_LOGIC
	);
end xga_clocks;

architecture Behavioral of xga_clocks is

   signal pixel_clock_unbuf     : std_logic;
	signal pixel_clockx5_unbuf	  : std_logic;
	signal pll_locked, clk_feedback: std_logic;

begin

   PLL_BASE_inst : PLL_BASE
  generic map
   (BANDWIDTH            => "OPTIMIZED",
    CLK_FEEDBACK         => "CLKFBOUT",
    COMPENSATION         => "SYSTEM_SYNCHRONOUS",
    DIVCLK_DIVIDE        => 2,
    CLKFBOUT_MULT        => 13,
    CLKFBOUT_PHASE       => 0.000,
    CLKOUT0_DIVIDE       => 2,
    CLKOUT0_PHASE        => 0.000,
    CLKOUT0_DUTY_CYCLE   => 0.500,
    CLKOUT1_DIVIDE       => 10,
    CLKOUT1_PHASE        => 0.000,
    CLKOUT1_DUTY_CYCLE   => 0.500,
    CLKIN_PERIOD         => 10.000,
    REF_JITTER           => 0.010)

--   generic map (
--      CLKFBOUT_MULT => 13,                  
--      CLKOUT0_DIVIDE => 2,       CLKOUT0_PHASE => 0.0,   -- Output 5x pixel clock frequency - 325 MHz
--      CLKOUT1_DIVIDE => 10,       CLKOUT1_PHASE => 0.0,   -- Output 1x pixel clock frequency - 65 MHz
--      CLK_FEEDBACK => "CLKFBOUT",                         -- Clock source to drive CLKFBIN ("CLKFBOUT" or "CLKOUT0")
--      CLKIN_PERIOD => 10.0,                              -- IMPORTANT! 100 MHz
--      DIVCLK_DIVIDE => 2                                 -- Division value for all output clocks (1-52)
--   )

      port map (
      CLKFBOUT => clk_feedback, 
      CLKOUT0  => pixel_clockx5_unbuf,
      CLKOUT1  => pixel_clock_unbuf,
      CLKOUT2  => open,
      CLKOUT3  => open,
      CLKOUT4  => open,
      CLKOUT5  => open,
      LOCKED   => pll_locked,      
      CLKFBIN  => clk_feedback,    
      CLKIN    => clk100, 
      RST      => '0'              -- 1-bit input: Reset input
   );

   BUFG_pclock   : BUFG port map ( I => pixel_clock_unbuf,  O => pixel_clock);
   BUFG_pclockx5 : BUFG port map ( I => pixel_clockx5_unbuf, O => clock_5x);

end Behavioral;



